<?php
/**
 * Block Patterns
 * 
 * @link https://developer.wordpress.org/reference/functions/register_block_pattern/
 * @link https://developer.wordpress.org/reference/functions/register_block_pattern_category/
 *
 * @package bigwigs
 * @since   0.7.0
 */

/**
 * Register Block Pattern Category.
 */
if ( function_exists( 'register_block_pattern_category' ) ) {
	register_block_pattern_category(
		'bigwigs',
		array( 'label' => __( 'Bigwigs Patterns', 'bigwigs' ) )
	);
}

/**
 * Register Block Patterns.
 */
if ( function_exists( 'register_block_pattern' ) ) {

	// Giant Heading.
	register_block_pattern(
		'bigwigs/giant-heading',
		array(
			'title'         => esc_html__( 'Giant Heading', 'bigwigs' ),
			'categories'    => array( 'bigwigs' ),
			'viewportWidth' => 1440,
			'content'       => '<!-- wp:heading {"align":"center"} --><h2 class="has-text-align-center display-1">' . esc_html__( 'Giant Heading', 'bigwigs' ) . '</h2><!-- /wp:heading -->',
		)
	);

	// Team member or Author box
	register_block_pattern(
		'bigwigs/author-box',
		array(
			'title'         => esc_html__( 'Author / Team member', 'bigwigs' ),
			'categories'    => array( 'bigwigs' ),
			'viewportWidth' => 1440,
			'content'       => '<!-- wp:media-text {"mediaId":1978,"mediaLink":"' . esc_url( get_template_directory_uri() ) . '/images/man-person.jpg","mediaType":"image","imageFill":true,"focalPoint":{"x":"0.50","y":"0.02"},"className":"border mt-4"} --><div class="wp-block-media-text alignwide is-stacked-on-mobile is-image-fill border mt-4"><figure class="wp-block-media-text__media" style="background-image:url('. esc_url( get_template_directory_uri() ) . '/images/man-person.jpg);background-position:50% 2%"><img src="'. esc_url( get_template_directory_uri() ) . '/images/man-person.jpg" alt="" class="wp-image-1978"/></figure>
				<div class="wp-block-media-text__content">
				<!-- wp:paragraph {"className":"badge badge-info mt-4"} -->
				<p class="badge badge-info mt-4">'. esc_html__( 'Manager', 'bigwigs' ) .'</p>
				<!-- /wp:paragraph -->
				<!-- wp:paragraph {"placeholder":"Content…","style":{"typography":{"fontSize":24}}} -->
				<p style="font-size:24px"><strong>'. esc_html__( 'George McDonnell', 'bigwigs' ) .'</strong></p>
				<!-- /wp:paragraph -->
				<!-- wp:paragraph -->
				<p>'. esc_html__( 'Ralesuada tempus risus, ut ullamcorper risus elementum.', 'bigwigs' ) .'</p>
				<!-- /wp:paragraph -->
				<!-- wp:social-links {"className":"is-style-logos-only"} -->
				<ul class="wp-block-social-links is-style-logos-only"><!-- wp:social-link {"url":"https://wordpress.org","service":"wordpress"} /-->
				<!-- wp:social-link {"url":"#","service":"facebook"} /-->
				<!-- wp:social-link {"url":"#","service":"twitter"} /-->
				<!-- wp:social-link {"service":"instagram"} /-->
				<!-- wp:social-link {"service":"linkedin"} /-->
				<!-- wp:social-link {"service":"youtube"} /--></ul>
				<!-- /wp:social-links -->
				</div></div>
				<!-- /wp:media-text -->',
		)
	);

	if ( class_exists( 'Getwid\Getwid' ) ) {

		// Cards 2 columns
		register_block_pattern(
			'bigwigs/cards-two-column',
			array(
				'title'         => esc_html__( 'Cards 2 columns', 'bigwigs' ),
				'categories'    => array( 'bigwigs' ),
				'viewportWidth' => 1440,
				'content'       => '<!-- wp:columns {"verticalAlignment":"top"} -->
									<div class="wp-block-columns are-vertically-aligned-top"><!-- wp:column {"verticalAlignment":"top"} -->
									<div class="wp-block-column is-vertically-aligned-top"><!-- wp:getwid/section {"skipLayout":true,"paddingTop":"none","paddingBottom":"none","paddingLeft":"none","paddingRight":"none","className":"card mt-4"} -->
									<div class="wp-block-getwid-section card mt-4"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-bottom-none getwid-padding-left-none getwid-padding-right-none"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:image {"id":1135,"sizeSlug":"large","className":"card-img-top"} -->
									<figure class="wp-block-image size-large card-img-top"><img src="' . esc_url( get_template_directory_uri() ) . '/images/shoe-1451923-pxhere.com.jpg" alt="" class="wp-image-1135"/></figure>
									<!-- /wp:image -->

									<!-- wp:getwid/section {"skipLayout":true,"horizontalAlign":"flex-start","paddingTop":"none","paddingLeft":"none","paddingRight":"none","className":"card-body"} -->
									<div class="wp-block-getwid-section card-body"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-left-none getwid-padding-right-none getwid-justify-content-flex-start"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:heading {"level":5,"className":"card-title"} -->
									<h5 class="card-title">'. esc_html__( 'Card title', 'bigwigs' ) .'</h5>
									<!-- /wp:heading -->

									<!-- wp:paragraph {"className":"card-text"} -->
									<p class="card-text">'. esc_html__( 'Paragraph', 'bigwigs' ) .'</p>
									<!-- /wp:paragraph --></div></div></div></div></div>
									<!-- /wp:getwid/section --></div></div></div></div></div>
									<!-- /wp:getwid/section --></div>
									<!-- /wp:column -->

									<!-- wp:column {"verticalAlignment":"top"} -->
									<div class="wp-block-column is-vertically-aligned-top"><!-- wp:getwid/section {"skipLayout":true,"paddingTop":"none","paddingBottom":"none","paddingLeft":"none","paddingRight":"none","className":"card mt-4"} -->
									<div class="wp-block-getwid-section card mt-4"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-bottom-none getwid-padding-left-none getwid-padding-right-none"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:image {"id":1135,"sizeSlug":"full","className":"card-img-top"} -->
									<figure class="wp-block-image size-full card-img-top"><img src="' . esc_url( get_template_directory_uri() ) . '/images/shoe-1451923-pxhere.com.jpg" alt="" class="wp-image-1135"/></figure>
									<!-- /wp:image -->

									<!-- wp:getwid/section {"skipLayout":true,"horizontalAlign":"flex-start","paddingTop":"none","paddingLeft":"none","paddingRight":"none","className":"card-body"} -->
									<div class="wp-block-getwid-section card-body"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-left-none getwid-padding-right-none getwid-justify-content-flex-start"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:heading {"level":5,"className":"card-title"} -->
									<h5 class="card-title">'. esc_html__( 'Card title', 'bigwigs' ) .'</h5>
									<!-- /wp:heading -->

									<!-- wp:paragraph {"className":"card-text"} -->
									<p class="card-text">'. esc_html__( 'Paragraph', 'bigwigs' ) .'</p>
									<!-- /wp:paragraph --></div></div></div></div></div>
									<!-- /wp:getwid/section --></div></div></div></div></div>
									<!-- /wp:getwid/section --></div>
									<!-- /wp:column --></div>
									<!-- /wp:columns -->',
			)
		);

		// Three columns of cards with footer
		register_block_pattern(
			'bigwigs/cards-w-footer',
			array(
				'title'         => esc_html__( 'Cards with footer', 'bigwigs' ),
				'categories'    => array( 'bigwigs' ),
				'viewportWidth' => 1440,
				'content'       => '<!-- wp:columns {"verticalAlignment":"top","align":"wide"} -->
									<div class="wp-block-columns alignwide are-vertically-aligned-top"><!-- wp:column {"verticalAlignment":"top"} -->
									<div class="wp-block-column is-vertically-aligned-top"><!-- wp:getwid/section {"skipLayout":true,"paddingTop":"none","paddingBottom":"none","paddingLeft":"none","paddingRight":"none","className":"card mt-4"} -->
									<div class="wp-block-getwid-section card mt-4"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-bottom-none getwid-padding-left-none getwid-padding-right-none"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:image {"id":1135,"sizeSlug":"large","className":"card-img-top"} -->
									<figure class="wp-block-image size-large card-img-top"><img src="' . esc_url( get_template_directory_uri() ) . '/images/shoe-1451923-pxhere.com.jpg" alt="" class="wp-image-1135"/></figure>
									<!-- /wp:image -->

									<!-- wp:getwid/section {"skipLayout":true,"horizontalAlign":"flex-start","paddingTop":"none","paddingLeft":"none","paddingRight":"none","className":"card-body"} -->
									<div class="wp-block-getwid-section card-body"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-left-none getwid-padding-right-none getwid-justify-content-flex-start"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:heading {"align":"left","level":5,"className":"card-title"} -->
									<h5 class="has-text-align-left card-title">'. esc_html__( 'Card title', 'bigwigs' ) .'</h5>
									<!-- /wp:heading -->

									<!-- wp:paragraph {"align":"left","className":"card-text"} -->
									<p class="has-text-align-left card-text">'. esc_html__( 'Paragraph', 'bigwigs' ) .'</p>
									<!-- /wp:paragraph -->

									</div></div></div></div></div>
									<!-- /wp:getwid/section -->

									<!-- wp:getwid/section {"skipLayout":true,"paddingTop":"none","paddingBottom":"none","paddingLeft":"none","paddingRight":"none","className":"card-footer text-muted"} -->
									<div class="wp-block-getwid-section card-footer text-muted"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-bottom-none getwid-padding-left-none getwid-padding-right-none"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:paragraph {"fontSize":"small"} -->
									<p class="has-small-font-size">'. esc_html__( 'Text', 'bigwigs' ) .'</p>
									<!-- /wp:paragraph --></div></div></div></div></div>
									<!-- /wp:getwid/section --></div></div></div></div></div>
									<!-- /wp:getwid/section --></div>
									<!-- /wp:column -->

									<!-- wp:column {"verticalAlignment":"top"} -->
									<div class="wp-block-column is-vertically-aligned-top"><!-- wp:getwid/section {"skipLayout":true,"paddingTop":"none","paddingBottom":"none","paddingLeft":"none","paddingRight":"none","className":"card mt-4"} -->
									<div class="wp-block-getwid-section card mt-4"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-bottom-none getwid-padding-left-none getwid-padding-right-none"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:image {"id":1135,"sizeSlug":"large","className":"card-img-top"} -->
									<figure class="wp-block-image size-large card-img-top"><img src="' . esc_url( get_template_directory_uri() ) . '/images/shoe-1451923-pxhere.com.jpg" alt="" class="wp-image-1135"/></figure>
									<!-- /wp:image -->

									<!-- wp:getwid/section {"skipLayout":true,"horizontalAlign":"flex-start","paddingTop":"none","paddingLeft":"none","paddingRight":"none","className":"card-body"} -->
									<div class="wp-block-getwid-section card-body"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-left-none getwid-padding-right-none getwid-justify-content-flex-start"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:heading {"align":"left","level":5,"className":"card-title"} -->
									<h5 class="has-text-align-left card-title">'. esc_html__( 'Card title', 'bigwigs' ) .'</h5>
									<!-- /wp:heading -->

									<!-- wp:paragraph {"align":"left","className":"card-text"} -->
									<p class="has-text-align-left card-text">'. esc_html__( 'Paragraph', 'bigwigs' ) .'</p>
									<!-- /wp:paragraph -->

									</div></div></div></div></div>
									<!-- /wp:getwid/section -->

									<!-- wp:getwid/section {"skipLayout":true,"paddingTop":"none","paddingBottom":"none","paddingLeft":"none","paddingRight":"none","className":"card-footer text-muted"} -->
									<div class="wp-block-getwid-section card-footer text-muted"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-bottom-none getwid-padding-left-none getwid-padding-right-none"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:paragraph {"fontSize":"small"} -->
									<p class="has-small-font-size">'. esc_html__( 'Text', 'bigwigs' ) .'</p>
									<!-- /wp:paragraph --></div></div></div></div></div>
									<!-- /wp:getwid/section --></div></div></div></div></div>
									<!-- /wp:getwid/section --></div>
									<!-- /wp:column -->

									<!-- wp:column {"verticalAlignment":"top"} -->
									<div class="wp-block-column is-vertically-aligned-top"><!-- wp:getwid/section {"skipLayout":true,"paddingTop":"none","paddingBottom":"none","paddingLeft":"none","paddingRight":"none","className":"card mt-4"} -->
									<div class="wp-block-getwid-section card mt-4"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-bottom-none getwid-padding-left-none getwid-padding-right-none"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:image {"id":1135,"sizeSlug":"large","className":"card-img-top"} -->
									<figure class="wp-block-image size-large card-img-top"><img src="' . esc_url( get_template_directory_uri() ) . '/images/shoe-1451923-pxhere.com.jpg" alt="" class="wp-image-1135"/></figure>
									<!-- /wp:image -->

									<!-- wp:getwid/section {"skipLayout":true,"horizontalAlign":"flex-start","paddingTop":"none","paddingLeft":"none","paddingRight":"none","className":"card-body"} -->
									<div class="wp-block-getwid-section card-body"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-left-none getwid-padding-right-none getwid-justify-content-flex-start"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:heading {"align":"left","level":5,"className":"card-title"} -->
									<h5 class="has-text-align-left card-title">'. esc_html__( 'Card title', 'bigwigs' ) .'</h5>
									<!-- /wp:heading -->

									<!-- wp:paragraph {"align":"left","className":"card-text"} -->
									<p class="has-text-align-left card-text">'. esc_html__( 'Paragraph', 'bigwigs' ) .'</p>
									<!-- /wp:paragraph -->

									</div></div></div></div></div>
									<!-- /wp:getwid/section -->

									<!-- wp:getwid/section {"skipLayout":true,"paddingTop":"none","paddingBottom":"none","paddingLeft":"none","paddingRight":"none","className":"card-footer text-muted"} -->
									<div class="wp-block-getwid-section card-footer text-muted"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-bottom-none getwid-padding-left-none getwid-padding-right-none"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:paragraph {"fontSize":"small"} -->
									<p class="has-small-font-size">'. esc_html__( 'Text', 'bigwigs' ) .'</p>
									<!-- /wp:paragraph --></div></div></div></div></div>
									<!-- /wp:getwid/section --></div></div></div></div></div>
									<!-- /wp:getwid/section --></div>
									<!-- /wp:column --></div>
									<!-- /wp:columns -->',
			)
		);

		// Wide card
		register_block_pattern(
			'bigwigs/wide-card',
			array(
				'title'         => esc_html__( 'Wide Card', 'bigwigs' ),
				'categories'    => array( 'bigwigs' ),
				'viewportWidth' => 1440,
				'content'       => '
									<!-- wp:getwid/section {"align":"wide","skipLayout":true,"contentMaxWidthPreset":"full","paddingTop":"none","paddingBottom":"none","paddingLeft":"none","paddingRight":"none","className":"card alignwide alignwide"} -->
									<div class="wp-block-getwid-section card alignwide alignwide getwid-section-content-full-width"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-bottom-none getwid-padding-left-none getwid-padding-right-none"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:getwid/section {"skipLayout":true,"paddingTop":"none","paddingBottom":"none","paddingLeft":"none","paddingRight":"none","className":"card-header"} -->
									<div class="wp-block-getwid-section card-header"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-bottom-none getwid-padding-left-none getwid-padding-right-none"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:paragraph {"align":"center","className":"mb-0"} -->
									<p class="has-text-align-center mb-0"><strong>'. esc_html__( 'Card Header', 'bigwigs' ) .'</strong></p>
									<!-- /wp:paragraph --></div></div></div></div></div>
									<!-- /wp:getwid/section -->

									<!-- wp:getwid/section {"skipLayout":true,"paddingTop":"medium","paddingBottom":"none","paddingLeft":"none","paddingRight":"none","className":"card-body"} -->
									<div class="wp-block-getwid-section card-body"><div class="wp-block-getwid-section__wrapper getwid-padding-top-medium getwid-padding-bottom-none getwid-padding-left-none getwid-padding-right-none"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:heading {"align":"center","level":5,"className":"card-title"} -->
									<h5 class="has-text-align-center card-title">'. esc_html__( 'Special title treatment', 'bigwigs' ) .'</h5>
									<!-- /wp:heading -->

									<!-- wp:paragraph {"align":"center","className":"card-text"} -->
									<p class="has-text-align-center card-text">'. esc_html__( 'With supporting text below as a natural lead-in to additional content', 'bigwigs' ) .'.</p>
									<!-- /wp:paragraph -->

									<!-- wp:buttons {"align":"center"} -->
									<div class="wp-block-buttons aligncenter"><!-- wp:button {"className":"is-style-outline"} -->
									<div class="wp-block-button is-style-outline"><a class="wp-block-button__link">'. esc_html__( 'Button', 'bigwigs' ) .'</a></div>
									<!-- /wp:button --></div>
									<!-- /wp:buttons --></div></div></div></div></div>
									<!-- /wp:getwid/section -->

									<!-- wp:getwid/section {"skipLayout":true,"paddingTop":"none","paddingBottom":"none","paddingLeft":"none","paddingRight":"none","className":"card-footer"} -->
									<div class="wp-block-getwid-section card-footer"><div class="wp-block-getwid-section__wrapper getwid-padding-top-none getwid-padding-bottom-none getwid-padding-left-none getwid-padding-right-none"><div class="wp-block-getwid-section__inner-wrapper"><div class="wp-block-getwid-section__background-holder"><div class="wp-block-getwid-section__background"></div><div class="wp-block-getwid-section__foreground"></div></div><div class="wp-block-getwid-section__content"><div class="wp-block-getwid-section__inner-content"><!-- wp:paragraph {"align":"center","className":"text-muted"} -->
									<p class="has-text-align-center text-muted">'. esc_html__( '2 days ago', 'bigwigs' ) .'</p>
									<!-- /wp:paragraph --></div></div></div></div></div>
									<!-- /wp:getwid/section --></div></div></div></div></div>
									<!-- /wp:getwid/section -->
				',
			)
		);
	}

}